#!/bin/bash
##
## This script is a wrapper before starting the actual job.
## It will setup working and temporary directories and
## error handlers for aborting and exiting in a well-defined fashion
##

## This function is executed when the script exits
cleanupOnExit()
{
	EXIT_CODE=$?
	## Remove temporary directory unless debugging
	cd ${WD}
	if [ -z "${JOB_DEBUG}" ] && [ -d "${TMPDIR}" ]; then
		rm -rf ${TMPDIR}
	fi
}

## Add handler for cleaning up after the job has ended
trap cleanupOnExit EXIT

## Create temporary directory and ensure that it is empty
mkdir -p ${TMPDIR}
rm -rf ${TMPDIR}/*

## Finally, we can now run the actual job
cd ${WD}
./job.sh
JOB_EXIT_CODE=$?

## Exit with the exit code from the job
## (not really needed in the current implementation since job.sh is the last cmd)
exit ${JOB_EXIT_CODE}
