var Remote = function()
{
	var remote = {};
	var debug = 0;

	remote.initPage = function()
	{
		var url = 'OpenGrid.servlet?ID='+App.getSessionId();
		url += '&cmd=GetHostInfo&jobAgentDetails=1';
		url += '&hostId='+encodeURIComponent(Data.get('page-data', 'host-id'));
		
		var request = Ajax.getXmlHttpRequest();
		request.open("GET", url, true);
		Ajax.setReadyStateHandler(request, remote.onHostInfoLoaded, remote.onHostInfoLoaded);
		request.send(null);
		
		// All other initialization happens after info has been loaded
	}
	
	remote.onHostInfoLoaded = function(request)
	{
		if (debug) App.debug(Strings.encodeTags(request.responseText));
		var response;
		var error = false;
		try
		{
			response = JSON.parse(request.responseText);
			if (response.status != 'ok')
			{
				error = response.message || response.stacktrace || 'Unexpected error';
			}
		}
		catch (ex)
		{
			error = ex;
		}
		
		if (error)
		{
			alert(error);
			return;
		}

		var host = response.host;
		var connectionInfo = host.connection;
		var hostInfo = host.clusterInfo.hostInfo;
		var openGridInfo = host.clusterInfo.openGridInfo;
		var config = host.config;
		
		Doc.element('host-name').innerHTML = Strings.encodeTags(connectionInfo.name);
		Doc.element('host-address').innerHTML = Strings.encodeTags(connectionInfo.address+':'+connectionInfo.port);
		Doc.element('username').innerHTML = Strings.encodeTags(connectionInfo.user);
		Doc.element('fingerprint').innerHTML = Strings.encodeTags(connectionInfo.fingerprint);
		
		Doc.element('ogs-type').innerHTML = Strings.encodeTags(config.type);
		Doc.element('cluster-info-cmd').innerHTML = Strings.encodeTags('> ' + hostInfo.cmd);
		Doc.element('cluster-info-result').innerHTML = remote.getCmdResultString(hostInfo);
		Doc.element('ogs-info-cmd').innerHTML = Strings.encodeTags('> ' + openGridInfo.cmd);
		Doc.element('ogs-info-result').innerHTML = remote.getCmdResultString(openGridInfo);
		
		Doc.element('time-cmd').innerHTML = Strings.encodeTags('> ' + config.dateCommand);
		Doc.element('time-diff').innerHTML = host.clusterInfo.timeAdjustment + ' seconds';

		Doc.element('job-agent').innerHTML = remote.getJobAgentString(config.jobAgent);
		Doc.element('job-folder').innerHTML = Strings.encodeTags(config.jobFolder);
		Doc.element('tmp-folder').innerHTML = Strings.encodeTags(config.tmpFolder);
		Doc.element('tmp-folder-debug').innerHTML = Strings.encodeTags(config.tmpFolderDebug);
		
		var nodes = '';
		if (config.nodes.length > 0)
		{
			nodes = '<ul>';
			for (var i = 0; i < config.nodes.length; i++)
			{
				nodes += '<li>'+Strings.encodeTags(config.nodes[i].name);
			}
			nodes += '</ul>';
		}
		else
		{
			nodes = '<i>Not configured</i>';
		}
		Doc.element('nodes').innerHTML = nodes;
		
		var linkedItems = document.getElementsByClassName('linked-item');
		for (var itemNo = 0; itemNo < linkedItems.length; itemNo++)
		{
			Events.addEventHandler(linkedItems[itemNo], 'click', Items.itemOnClick);
		}
		
		var sharedItems = document.getElementsByClassName('shared-item');
		for (var itemNo = 0; itemNo < sharedItems.length; itemNo++)
		{
			Events.addEventHandler(sharedItems[itemNo], 'click', Buttons.shareItem);
		}
	}
	
	remote.getCmdResultString = function(cmdData)
	{
		var r = '';
		if (cmdData.exitStatus != 0)
		{
			r += '<div class="stderr">['+cmdData.exitStatus+'] ';
			r += Strings.encodeTags(cmdData.stderr);
			r += '</div>';
		}
		else
		{
			r += '<div class="stdout">';
			r += Strings.encodeTags(cmdData.stdout);
			r += '</div>';
		}
		return r;
	}
	
	remote.getJobAgentString = function(jobAgent)
	{
		var html = '';
		if (!jobAgent)
		{
			html = '<i>Not connected</i>';
		}
		else if (jobAgent.exception)
		{
			html = Strings.encodeTags(jobAgent.externalId + ' [' + jobAgent.exception + ']');
		}
		else
		{
			if (jobAgent.isShared)
			{
				html += '<span class="icon link shared-item" title="Set access permissions" data-item-type="JOBAGENT" data-item-id="'+jobAgent.id+'">';
				html += '<img src="../../images/shared.png"></span> ';
			}
			html += '<span class="link linked-item" title="View/edit this job agent" data-item-type="JOBAGENT" data-item-id="'+jobAgent.id+'">';
			html += Strings.encodeTags(jobAgent.externalId)+'</span>';
		}
		return html;
	}
	
	return remote;
}();

Doc.onLoad(Remote.initPage);
